@@ -3,7 +3,7 @@
 set -e
 
 version=$1
-
+branch=$(git branch --show-current)
 TMPDIR=$(mktemp -d)
 
 echo "Installing to $TMPDIR for Horizon $version"
@@ -12,7 +12,7 @@ mkdir -p $TMPDIR/lib
 
 grep -i xstatic requirements.txt > $TMPDIR/requirements.txt
 
-pip3 install --system -t $TMPDIR/lib -r $TMPDIR/requirements.txt -c https://git.openstack.org/cgit/openstack/requirements/plain/upper-constraints.txt
+pip3 install -t $TMPDIR/lib -r $TMPDIR/requirements.txt -c "https://opendev.org/openstack/requirements/raw/branch/$branch/upper-constraints.txt"
 
 (
     cd $TMPDIR/lib
@@ -24,5 +24,13 @@ pip3 install --system -t $TMPDIR/lib -r $TMPDIR/requirements.txt -c https://git.
     tar -czf horizon_${version}.orig-xstatic.tar.gz *
 )
 
-mv  $TMPDIR/lib/horizon_${version}.orig-xstatic.tar.gz ../
+mkdir -p ../build-area/
+mv  $TMPDIR/lib/horizon_${version}.orig-xstatic.tar.gz ../build-area/
 rm -rf $TMPDIR
+
+rm -Rf xstatic
+mkdir xstatic
+tar -zxf ../build-area/horizon_${version}.orig-xstatic.tar.gz
+git add --all xstatic
+debchange --append "Refresh xstatic assets."
+debcommit --all
